#ifndef INC_DCCONTROL_H
#define INC_DCCONTROL_H

/** @file xidcusb.h
 *		@brief Header file for XIDCUSB library
 */ 

#if defined(WIN32) || defined(WIN64)
// for linking with DEF-file
#define DCCONTROL_API __stdcall
#else
#define DCCONTROL_API __attribute__((visibility("default")))
#endif

#if defined(__cplusplus)
extern "C"
{
#endif

	/**
		* \def DCCONTROL_API
		* \brief Library import macros.
		* Macros allows to automatically import function from shared library.
		* It automatically expands to dllimport on msvc when including header file
		*/

	// msvc types burden
#ifdef _MSC_VER
	typedef unsigned __int8 uint8_t;
	typedef unsigned __int32 uint32_t;
#endif

	/**
		\english
		* Type describes device identifier
		\endenglish
		\russian
		* Тип идентификатора устройства
		\endrussian
		*/
	typedef int device_t;

	/**
		\english
		* Type specifies result of any XIDC operation
		\endenglish
		\russian
		* Тип, определяющий результат выполнения команды.
		\endrussian
		*/
	typedef int result_t;

	/**
		\english
		* Handle specified undefined device
		\endenglish
		\russian
		* Макрос, означающий неопределенное устройство
		\endrussian
		*/
#define device_undefined -1

	/** \english
		@name Result statuses
		\endenglish
		\russian
		@name Результаты выполнения команд
		\endrussian
		*/
	//@{

	/**
		\english
		* success
		\endenglish
		\russian
		* выполнено успешно
		\endrussian
		*/
#define result_ok 0

	/**
		\english
		* generic error
		\endenglish
		\russian
		* общая ошибка
		\endrussian
		*/
#define result_error -1

	/**
		\english
		* function is not implemented
		\endenglish
		\russian
		* функция не определена
		\endrussian
		*/
#define result_not_implemented -2

	/**
		\english
		* device reports wrong request or response
		\endenglish
		\russian
		* ошибка в запросе или в ответе
		\endrussian
		*/
#define result_dataerror -3

	/**
		\english
		* device is lost
		\endenglish
		\russian
		* устройство не подключено
		\endrussian
		*/
#define result_nodevice -4

	//@}

	// ------------------------------------

	/**
		* \english
		* Describes motor state
		* \endenglish
		* \russian
		* Состояние мотора
		* \endrussian
		*/
	typedef enum {
		DevStateOff,				/**< \english motor is turned off. \endenglish \russian мотор отключен от контроллера. \endrussian */
		DevStateStop,				/**< \english motor is stopped. \endenglish \russian мотор остановлен. \endrussian */
		DevStateMoving,				/**< \english motor is moving. \endenglish \russian мотор работает. \endrussian */
		DevStateTune,				/**< \english motor is tuning. \endenglish \russian мотор находится в состоянии точной доводки. \endrussian */
		DevStateHoming,				/**< \english motor is going to home position. \endenglish \russian мотор двигается в начальную позицию. \endrussian */
		DevStateCalibr = 0x0C,		/**< \english motor is calibrating. \endenglish \russian мотор находится в состоянии калибровки. \endrussian */
		DevStateAlarm = 0x0A		/**< \english engine in alarm state. \endenglish \russian контроллер находится в аварийном состоянии, мотор отключен от контроллера. \endrussian */
	} DevState;

	/**
		* \english
		* Describes PWM state.
		* Pulse-width modulation (PWM) module drive MOSFET full brige that control current through the motor
		* \endenglish
		* \russian
		* Состояние ШИМ.
		* Модуль ШИМ (широтно-импульсная модуляция) управляет силовыми MOSFET ключами, регулируя ток через мотор.
		* \endrussian
		*/
	typedef enum {
		PwmStateOff,			/**< \english PWM is off, motor winding is cut off power. \endenglish \russian ШИМ выключен, мотор отключен от контроллера. \endrussian */
		PwmStateBrak,			/**< \english braking mode, motor winding is closed. \endenglish \russian режим блокировки, выводы мотора закорочены. \endrussian */
		PwmStateRunfwd,			/**< \english motor running forward. \endenglish \russian мотор вращается вправо \endrussian */
		PwmStateRunbck,			/**< \english motor running backward. \endenglish \russian мотор вращается влево \endrussian */
		PwmStateInvbrak			/**< \english inverted braking mode. \endenglish \russian режим обратной блокировки, используется для калибровки в сервисных целях. \endrussian */
	} PwmState;

	/** 
		* \english
		* Describes synchronization pin mode
		* \endenglish
		* \russian
		* Тип вывода синхронизации
		* \endrussian
		*/
	typedef enum {
		PinGPIO				= 0x00,		/**< \english GPIO. \endenglish \russian GPIO. \endrussian */
		PinSyncIn			= 0x01,		/**< \english sync in. \endenglish \russian вход синхронизации. \endrussian */
		PinSyncOut			= 0x02		/**< \english sync out. \endenglish \russian выход синхронизации. \endrussian */
	} SyncPinMode;

	/** \english
		@name Status flags
		* Controller flags returned by device query.
		* Contains boolean part of controller status.
		* May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги состояния
		* Содержат бинарные значения состояния контроллера. Могут быть объединены с помощью логического ИЛИ.
		\endrussian
		* @see state_t::flags
		* @see get_status
		*/
	//@{
#define STATE_RIGHT_EDGE		0x0001		/**< \english Engine stucks at the right edge \endenglish \russian Достижение правой границы \endrussian */
#define STATE_LEFT_EDGE			0x0002		/**< \english Engine stucks at the left edge \endenglish \russian Достижение левой границы \endrussian */
#define STATE_EXT_POWER			0x0004		/**< \english External power is used \endenglish \russian Используется внешнее питание \endrussian */
#define STATE_ERRC				0x0008		/**< \english Command error encountered \endenglish \russian Недопустимая команда \endrussian  */
#define STATE_ERRD				0x0010		/**< \english Data error encountered \endenglish \russian Недопустимые данные \endrussian */
#define STATE_POWER_DISABLE		0x0020		/**< \english FTDI reports "Power disable" \endenglish \russian Получено сообщение от FTDI об отключении USB-питания \endrussian */
#define STATE_TTLIO_PINOUT		0x0040		/**< \english Synchronization In/Out works as Out, if flag set; otherwise works as In \endenglish \russian Если флаг установлен, вывод синхронизации работает как выход; если флаг сброшен, вывод работает как вход. \endrussian */
#define STATE_TTLIO_LEVEL		0x0080		/**< \english State of synchronization In/Out pin \endenglish \russian Лог. уровень на выводе синхронизации \endrussian */
#define STATE_BUTTON_RIGHT		0x0100		/**< \english Button "right" state (1 if pressed) \endenglish \russian Состояние кнопки "вправо" (1, если нажата). \endrussian */
#define STATE_BUTTON_LEFT		0x0200		/**< \english Button "left" state (1 if pressed) \endenglish \russian Состояние кнопки "влево" (1, если нажата). \endrussian */
#define STATE_OVERHEAT			0x2000		/**< \english Temperature sensor show value that exceed maximum temperature rating less then 1 ms \endenglish \russian Температура превысила допустимую вличину. Время реакции меньше 1 мс. \endrussian */
#define STATE_OVERLOAD_VOLTAGE	0x4000		/**< \english Voltage overload encountered. Voltage drop on motor exceed maximum rating less then 1 ms \endenglish \russian Перегрузка по напряжению. Время реакции меньше 1 мс. \endrussian */
#define STATE_OVERLOAD_CURRENT	0x8000		/**< \english Current overlaod encountered. Motor current exceed maximum rating less then 1 ms \endenglish \russian Перегрузка по току. Время реакции меньше 1 мс. \endrussian */
	//@}

	/** \english
		@name Flags of engine settings
		* Specify motor shaft movement algorithm and list of limitations.
		* Flags returned by query of engine settings. May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги параметров мотора
		* Определяют настройки движения и работу ограничителей.
		* Возращаются командой get_engine_settings. Могут быть объединены с помощью логического ИЛИ.
		\endrussian
		* @see engine_settings_t::flags
		* @see set_engine_settings
		* @see get_engine_settings
		*/
	//@{
#define ENGINE_REVERSE				0x0001		/**< \english Reverse flag. It determines motor shaft rotation direction that corresponds to feedback counts increasing. If not set (default), motor shaft rotation direction under positive voltage corresponds to feedback counts increasing and vice versa. Change it if you see that positive directions on motor and feedback are opposite \endenglish \russian Флаг реверса. Связывает направление вращения мотора с направлением счета текущей позиции. При сброшенном флаге (по умолчанию) прикладываемое к мотору положительное напряжение увеличивает счетчик позиции. И наоборот, при установленном флаге счетчик позиции увеличивается, когда к мотору приложено отрицательное напряжение. Измените состояние флага, если положительное вращение мотора уменьшает счетчик позиции. \endrussian */
#define ENGINE_FINISHING			0x0002		/**< \english Fine tuneup flag. If it set, engine makes special tuneup procedure and reach the predetermined end position accurately on low speed \endenglish \russian Флаг точной доводки. Если флаг установлен, мотор выполняет специальные действия для быстрого и точного достижения заданной позиции. \endrussian */
#define ENGINE_MAX_SPEED			0x0004		/**< \english Max speed flag. If it is set, engine uses maxumum speed achievable with the present engine settings as nominal speed \endenglish \russian Флаг максимальной скорости. Если флаг установлен, движение происходит на максимальной скорости. \endrussian */
#define ENGINE_ANTIPLAY				0x0008		/**< \english Play compensation flag. If it set, engine makes backlash (play) compensation procedure and reach the predetermined position accurately on low speed \endenglish \russian Компенсация люфта. Если флаг установлен, позиционер будет подходить к заданной точке всегда с одной стороны. Например, при подходе слева никаких дополнительных действий не совершается, а при подходе справа позиционер проходит целевую позицию на заданное расстояния и возвращается к ней опять же справа. \endrussian */
#define ENGINE_ACCEL_ON				0x0010		/**< \english Acceleration enable flag. If it set, motion begins with acceleration and ends with deceleration \endenglish \russian Ускорение. Если флаг установлен, движение происходит с ускорением.  \endrussian */
#define ENGINE_LIMIT_VOLT			0x0020		/**< \english Maxumum motor voltage limit enable flag \endenglish \russian Номинальное напряжение мотора. Если флаг установлен, напряжение на моторе ограничивается заданным номинальным значением. \endrussian */
#define ENGINE_LIMIT_CURR			0x0040		/**< \english Maxumum motor current limit enable flag \endenglish \russian Номинальный ток мотора. Если флаг установлен, ток через мотор ограничивается заданным номинальным значением. \endrussian */
#define ENGINE_LIMIT_RPM			0x0080		/**< \english Maxumum motor speed limit enable flag \endenglish \russian Номинальная частота вращения мотора. Если флаг установлен, частота вращения ограничивается заданным номинальным значением. \endrussian */
#define ENGINE_HOLD					0x0100		/**< \english Hold motor shaft when motor is stopped if this flag set \endenglish \russian Режим удержания. Ротор мотора удерживается в заданной позиции, если флаг установлен. \endrussian */
#define ENGINE_DYNAMIC_HOLD			0x0200		/**< \english Holding motor shaft dynamically (power supply is applied to motor always), if set; when shaft position is different from specified, if not set \endenglish \russian Динамическое удержание. Если флаг установлен, воздействие мотора не прекращается при достижении заданной позиции, контроллер остается в состоянии Tune. Если флаг сброшен, при достижении заданной позиции контроллер переходит в состояние Stop,Brake. \endrussian */
#define ENGINE_ONLY_FINISHING		0x0400		/**< \english Move in fine tuneup mode only if this flag set. Do not use this flag in normal operation mode. It used for PID tuning only \endenglish \russian Если флаг установлен, движение к точке начинается сразу в состоянии Tune. Это специальный режим, который используется при настройке ПИД контура. Не используйте его в обычной работе. \endrussian */
	//@}

	/** \english
		@name Flags of microstep mode
		* Specify settings of microstep mode. Used with step motors.
		* Flags returned by query of engine settings. May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги параметров микрошагового режима
		* Определяют деление шага в микрошаговом режиме. Используются с шаговыми моторами.
		* Возращаются командой get_engine_settings. Могут быть объединены с помощью логического ИЛИ.
		\endrussian
		* @see engine_settings_t::flags
		* @see set_engine_settings
		* @see get_engine_settings
		*/
	//@{
#define MICROSTEP_MODE_FULL			0x01	/**< \english Full step mode. \endenglish \russian Полношаговый режим. \endrussian */
#define MICROSTEP_MODE_FRAC_2		0x02	/**< \english 1/2 step mode. \endenglish \russian Деление шага 1/2. \endrussian */
#define MICROSTEP_MODE_FRAC_4		0x04	/**< \english 1/4 step mode. \endenglish \russian Деление шага 1/4. \endrussian */
#define MICROSTEP_MODE_FRAC_8		0x08	/**< \english 1/8 step mode. \endenglish \russian Деление шага 1/8. \endrussian */
#define MICROSTEP_MODE_FRAC_16		0x10	/**< \english 1/16 step mode. \endenglish \russian Деление шага 1/16. \endrussian */
#define MICROSTEP_MODE_FRAC_32		0x20	/**< \english 1/32 step mode. \endenglish \russian Деление шага 1/32. \endrussian */
#define MICROSTEP_MODE_FRAC_64		0x40	/**< \english 1/64 step mode. \endenglish \russian Деление шага 1/64. \endrussian */
#define MICROSTEP_MODE_FRAC_128		0x80	/**< \english 1/128 step mode. \endenglish \russian Деление шага 1/128. \endrussian */
	//@}

	/** \english
		@name Flags of engine type
		* Specify motor type.
		* Flags returned by query of engine settings.
		\endenglish
		\russian
		@name Флаги, определяющие тип мотора
		* Определяют тип мотора.
		* Возращаются командой get_engine_settings.
		\endrussian
		* @see engine_settings_t::flags
		* @see set_engine_settings
		* @see get_engine_settings
		*/
	//@{
#define ENGINE_TYPE_DC				0x01	/**< \english DC motor. \endenglish \russian Мотор постоянного тока. \endrussian */
#define ENGINE_TYPE_STEP			0x02	/**< \english Step motor. \endenglish \russian Шаговый мотор. \endrussian */
#define ENGINE_TYPE_BRUSHLESS		0x04	/**< \english Brushless motor. \endenglish \russian Безщеточный мотор. \endrussian */
	//@}


	/** 
		* \english
		* Describes feedback type
		* \endenglish
		* \russian
		* Тип обратной связи
		* \endrussian
		* @see set_feedback_settings 
		* @see get_feedback_settings 
		*/
		
	//@{
#define FEEDBACK_POTENTIOMETER		0x00	/**< \english feedback by potentiometer. \endenglish \russian обратная связь с помощью потенциометра. \endrussian */
#define	FEEDBACK_ENCODER			0x01	/**< \english feedback by encoder. \endenglish \russian обратная связь с помощью энкодера. \endrussian */
#define	FEEDBACK_ENCODERDIFF		0x02	/**< \english feedback by encoder with differential input. \endenglish
												 \russian обратная связь с помощью энкодера с дифференциальным входом. \endrussian */
#define	FEEDBACK_ENCODERHALL		0x04	/**< \english feedback by Hall detector. \endenglish \russian обратная связь с помощью датчика Холла. \endrussian */
#define	FEEDBACK_EMF				0x08	/**< \english feedback by EMF. \endenglish \russian обратная связь по ЭДС. \endrussian */
#define	FEEDBACK_NONE				0x10	/**< \english feedback is absent. \endenglish \russian обратная связь отсутствует. \endrussian */
	//@}


	/** \english
		@name Flags of synchronization In/Out setup
		\endenglish
		\russian
		@name Флаги настроек синхронизации входа/выхода
		\endrussian
		* @see sync_settings_t::setup_flags
		* @see get_sync_settings
		* @see set_sync_settings
		*/
	//@{
#define TTL_SETUP_DIROUT		0x0001	/**< \english Synchronization In/Out works as Out, if flag set; otherwise works as In \endenglish \russian Если флаг установлен, вывод синхронизации работает как выход; если флаг сброшен, вывод синхронизации работает как вход. \endrussian */
#define TTL_SETUP_OUTSET		0x0002	/**< \english Value on Synchronization Out, used if direction is out only \endenglish \russian Флаг определяет логический уровень на выводе синхронизации, установленном как выход. \endrussian */
#define TTL_SETUP_FRONT			0x0010	/**< \english Synchronization In mode. Response on front, if set. Response on cut, if not set \endenglish \russian Настройка синхронизации в режиме входа. Если флаг установлен, срабатывание происходит по фронту импульса. Если флаг сброшен, срабатывание происходит по спаду импульса. \endrussian */
	//@}

	/** \english
		@name Flags for synchronization input setup
		\endenglish
		\russian
		@name Флаги настроек синхронизации входа
		\endrussian
		* @see sync_settings_t::syncin_flags
		* @see get_sync_settings
		* @see set_sync_settings
		*/
	//@{
#define TTL_SYNCIN_ONMOVE			0x0001	/**< \english Infinite moving in TTL_SYNCIN_DIRRIGHT direction, if set; moving to given position or given shift, if not set \endenglish \russian Бесконечное вращение в направлении TTL_SYNCIN_DIRRIGHT, если флаг установлен; иначе - смещение на заданную позицию. \endrussian */
#define TTL_SYNCIN_MULTI_SHIFT		0x0004	/**< \english Response on every incoming pulse, if set; one time response, if not set \endenglish \russian Если флаг установлен, происходит многократное срабатывание по команде SHIFT; если сброшен - однократное срабатывание по команде MOVE. \endrussian */
#define TTL_SYNCIN_DIRRIGHT			0x0008	/**< \english Movement direction to the right, if set. Used when TTL_SYNCIN_ONMOVE set \endenglish \russian Направление вращения при синхронизации. Если флаг установлен, вращение вправо. Если флаг сброшен - влево. Используется, когда установлен флаг TTL_SYNCIN_ONMOVE. \endrussian */
	//@}

	/** \english
		@name Flags of synchronization output
		\endenglish
		\russian
		@name Флаги настроек синхронизации выхода
		\endrussian
		* @see sync_settings_t::syncout_flags
		* @see get_sync_settings
		* @see set_sync_settings
		*/
	//@{
#define TTL_SYNCOUT_ONSTART		0x0001	/**< \english Generate synchronization pulse when moving started \endenglish \russian Генерация синхронизирующего импульса при начале движения. \endrussian */
#define TTL_SYNCOUT_ONSTOP		0x0002	/**< \english Generate synchronization pulse when moving stopped \endenglish \russian Генерация синхронизирующего импульса при остановке. \endrussian */
#define TTL_SYNCOUT_ONPERIOD	0x0004	/**< \english Generate synchronization pulse every impulse_period encoder pulses \endenglish \russian Генерация синхронизирующего импульса при каждом импульсе энкодера. \endrussian */
	//@}

	/** \english
		@name Border flags
		* Specify types of borders and motor behaviour on borders.
		* May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги границ
		* Типы границ и поведение позиционера на границах.
		* Могут быть объединены с помощью побитового ИЛИ.
		\endrussian
		* @see get_edges_settings
		* @see set_edges_settings
		*/
	//@{
#define BORDER_IS_ENCODER		0x0001	/**< \english Borders are fixed by predetermined encoder values, if set; borders position on limit switches, if not set \endenglish \russian Если флаг установлен, границы определяются предустановленными точками на шкале позиции. Если флаг сброшен, границы определяются концевыми выключателями. \endrussian */
#define BORDER_STOP_LEFT		0x0002	/**< \english Motor should stop on left border \endenglish \russian Если флаг установлен, мотор останавливается при достижении левой границы. \endrussian */
#define BORDER_STOP_RIGHT		0x0004	/**< \english Motor should stop on right border \endenglish \russian Если флаг установлен, мотор останавливается при достижении правой границы. \endrussian */
	//@}

	/** \english
		@name Limit switches flags
		* Specify electrical behaviour of limit switches like order and pulled positions.
		* May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги концевых выключателей
		* Определяют направление и состояние границ. 
		* Могут быть объединены с помощью побитового ИЛИ.
		\endrussian
		* @see get_edges_settings
		* @see set_edges_settings
		*/
	//@{
#define ENDER_DIRECT		0x0001	/**< \english First limit switch on the right side, if set; otherwise on the left side \endenglish \russian Если флаг установлен, первый концевой выключатель находится справа; иначе - слева. \endrussian */
#define ENDER_ON1			0x0002	/**< \english First limit switch pulled position is closed, if set; otherwise pulled position is opened \endenglish \russian Если флаг установлен, первый концевой выключатель является нормально замкнутым; иначе - нормально разомкнутым. \endrussian */
#define ENDER_ON2			0x0004	/**< \english Second limit switch pulled position is closed, if set; otherwise pulled position is opened \endenglish \russian Если флаг установлен, второй концевой выключатель является нормально замкнутым; иначе - нормально разомкнутым. \endrussian */
	//@}


	/** \english
		@name Home settings flags
		* Specify behaviour for home command.
		* May be combined with bitwise OR
		\endenglish
		\russian
		@name Флаги настроек команды home
		* Определяют поведение для команды home
		* Могут быть объединены с помощью побитового ИЛИ.
		\endrussian
		* @see get_home_settings
		* @see set_home_settings
		* @see command_home
		*/
	//@{
#define HOME_DIR_FAST	0x01	/**< \english Flag defines direction of 1st motion after execute home command. Direction is right, if set; otherwise left. \endenglish \russian Определяет направление первоначального движения мотора после поступления команды HOME. Если флаг установлен - вправо; иначе - влево. \endrussian */
#define HOME_STOP_FAST	0x02	/**< \english Fast motion stops by synchronization input, if set; otherwise by limit switch. \endenglish \russian Если флаг установлен, то первоначальное движение завершается по сигналу со входа синхронизации; иначе - по сигналу с концевого выключателя. \endrussian */
#define HOME_DIR_SLOW	0x04	/**< \english Flag defines direction of 2nd motion. Direction is right, if set; otherwise left. \endenglish \russian  Определяет направление второго движения мотора. Если флаг установлен - вправо; иначе - влево. \endrussian */
#define HOME_REV_EN		0x08	/**< \english Revolution sensor is used, if set; otherwise this action passed. \endenglish \russian Если флаг установлен, используется Revolution sensor; иначе - этап пропускается. \endrussian */

	// ------------------------------------
	/** 
		* \english
		* Device state.
		* Useful structure that contains current controller status, including speed, position and boolean flags
		* \endenglish
		* \russian
		* Состояние устройства. 
		* Эта структура содержит основные параметры текущего состоянии контроллера такие как скорость, позиция и флаги состояния.
		* \endrussian
		* @see get_status
		*/
	typedef struct
	{
		DevState device_state;				/**< \english Device state \endenglish \russian Состояние устройства \endrussian */
		PwmState pwm_state;					/**< \english PWM state, PWM module drive MOSFET full brige that control current through the motor \endenglish \russian Состояние ШИМ \endrussian */
		unsigned int flags;					/**< \english Set of flags specify motor shaft movement algorithm and list of limitations \endenglish \russian Флаги состояния \endrussian */
		unsigned int current_position;		/**< \english Motor shaft position \endenglish \russian Текущая позиция \endrussian */
		int current_rpm;					/**< \english Motor shaft speed, RPM \endenglish \russian Текущая скорость, RPM \endrussian */
		int current_input;					/**< \english Engine current \endenglish \russian Ток через мотор \endrussian */
		int current_engine_voltage;			/**< \english Current average engine voltage \endenglish \russian Текущее усредненное напряжение на моторе \endrussian */
		int current_power_voltage;			/**< \english Power supply voltage \endenglish \russian Напряжение питания \endrussian */
		int current_temp;					/**< \english MOSFET full brige temperature \endenglish \russian Температура MOSFET ключей \endrussian */
	} state_t;

	/** 
		* \english
		* Additional device state.
		* This structure contains additional values such as winding's voltages, currents and temperature.
		* \endenglish
		* \russian
		* Дополнительное состояние устройства.
		* Эта структура содержит основные дополнительные параметры текущего состоянии контроллера, такие напряжения и токи обмоток и температуру.
		* \endrussian
		* @see get_status
		*/
	typedef struct
	{
		int winding_voltage_a;		/**< \english Winding A voltage \endenglish \russian Напряжение на обмотке А \endrussian */
		int winding_voltage_b;		/**< \english Winding B voltage \endenglish \russian Напряжение на обмотке B \endrussian */
		int winding_voltage_c;		/**< \english Winding C voltage \endenglish \russian Напряжение на обмотке C \endrussian */
		int winding_current_a;		/**< \english Winding A current \endenglish \russian Ток через обмотке А \endrussian */
		int winding_current_b;		/**< \english Winding B current \endenglish \russian Ток через обмотке B \endrussian */
		int winding_current_c;		/**< \english Winding C current \endenglish \russian Ток через обмотке C \endrussian */
		int current_temp;			/**< \english Temperature of MOSFET keys \endenglish \russian Температура MOSFET ключей \endrussian */
	} chart_data_t;

	/** 
		* \english
		* Calibration settings.
		* This structure contains calibration settings for all analog data from ADC embedded on board.
		* Range: -32767..32767.
		* All boards are supplied with full set of calibration data on controller's flash memory.
		* There is no necessity to change it during normal operation.
		* These data have to be changed after special device recalibraton only.
		* If you want to recalibrate board please consult with the manufacturer.
		* Wrong calibration settings lead to device malfunction, can lead to irreversible damage of board
		* \endenglish
		* \russian
		* Калибровочные коэффициенты.
		* Эта структура содержит коэффициенты, которые используются для преобразования данных с АЦП в используемые единицы измерения.
		* Диапазон: -32767..32767.
		* В контроллере эти коэффициенты хранятся в энергонезависимой flash памяти.
		* Все устройства при изготовлении проходят процедуру калибровки и при обычной работе их не требуется изменять.
		* Если вы хотите произвести калибровку устройства, проконсультируйтесь с производителем.
		* Неправильные коэффициенты могут быть причиной перегрева и выхода контроллера из строя.
		* \endrussian
		* @see get_calibration_coeffs
		* @see set_calibration_coeffs
		*/
	typedef struct
	{
		int amp_vout1;		/**< \english Scale factor for "Voltage out1" \endenglish \russian Коэффициент усиления для "Выходного напряжения 1" \endrussian */
		int amp_vout2;		/**< \english Scale factor for "Voltage out2" \endenglish \russian Коэффициент усиления для "Выходного напряжения 2" \endrussian */
		int amp_vext;		/**< \english Scale factor for "Supply voltage" \endenglish \russian Коэффициент усиления для "Напряжения внешнего питания" \endrussian */
		int amp_vkey;		/**< \english Scale factor for raw voltage on the top of MOSFET full brige \endenglish \russian Коэффициент уисления для "Напряжения питания ключей Н-моста" \endrussian */
		int amp_engcur;		/**< \english Scale factor for "Engine current" \endenglish \russian Коэффициент усиления для "Тока через мотор" \endrussian */
		int amp_tempkey;	/**< \english Scale factor for raw data from temperature sensor \endenglish \russian Коэффициент усиления для "Температуры MOSFET ключей" \endrussian */
		int off_vout1;		/**< \english Offset factor for "Voltage out1" \endenglish \russian Коэффициент смещения для "Выходного напряжения 1" \endrussian */
		int off_vout2;		/**< \english Offset factor for "Voltage out2" \endenglish \russian Коэффициент смещения для "Выходного напряжения 2" \endrussian */
		int off_vext;		/**< \english Offset factor for "Supply voltage" \endenglish \russian Коэффициент смещения для "Напряжения внешнего питания" \endrussian */
		int off_vkey;		/**< \english Offset factor for raw voltage on the top of MOSFET full brige \endenglish \russian Коэффициент смещения для "Напряжения питания ключей Н-моста" \endrussian */
		int off_engcur;		/**< \english Offset factor for "Engine current" \endenglish \russian Коэффициент смещения для "Тока через мотор" \endrussian */
		int off_tempkey;	/**< \english Offset factor for raw data from temperature sensor \endenglish \russian Коэффициент смещения для "Температуры MOSFET ключей" \endrussian */
	} calibration_settings_t;

	/** 
		* \english
		* Engine settings.
		* This structure contains useful motor settings.
		* These settings specify motor shaft movement algorithm, list of limitations and rated characteristics.
		* All boards are supplied with standart set of engine setting on controller's flash memory.
		* Please load new engine settings when you change motor, encoder, positioner etc.
		* Please note that wrong engine settings lead to device malfunction, can lead to irreversible damage of board
		* \endenglish
		* \russian
		* Настройки мотора.
		* Эта структура содержит настройки мотора. 
		* Настройки определяют номинальные значения напряжения, тока, скорости мотора, характер движения и тип мотора.
		* Пожалуйста, загружайте новые настройки когда вы меняете мотор, энкодер или позиционер.
		* Помните, что неправильные настройки мотора могут повредить оборудование.
		* \endrussian
		* @see set_engine_settings
		* @see get_engine_settings
		*/
	typedef struct
	{
		unsigned int nom_voltage;		/**< \english Rated voltage. Controller will keep the voltage drop on motor below this value if ENGINE_LIMIT_VOLT flag is set. Range: 1..65535 \endenglish \russian Номинальное напряжение мотора. Контроллер будет сохранять напряжение на моторе не выше  номинального, если установлен флаг ENGINE_LIMIT_VOLT. Диапазон: 1..65535 \endrussian */
		unsigned int nom_input;			/**< \english Rated current. Controller will keep current consumed by motor below this value if ENGINE_LIMIT_CURR flag is set. Range: 1..65535 \endenglish \russian Номинальный ток через мотор. Контроллер будет сохранять ток через мотор не выше номинального, если установлен флаг ENGINE_LIMIT_CURR. Диапазон: 1..65535 \endrussian */
		unsigned int nom_rpm;			/**< \english Rated RPM. Controller will keep motor shaft RPM below this value if ENGINE_LIMIT_RPM flag is set. Range: 1..65535 \endenglish \russian Номинальная скорость мотора. Контроллер будет сохранять скорость мотора не выше номинальной, если установлен флаг ENGINE_LIMIT_RPM. \endrussian */
		unsigned int flags;				/**< \english Set of flags specify motor shaft movement algorithm and list of limitations \endenglish \russian Флаги, управляющие работой мотора. \endrussian */
		int antiplay;					/**< \english Number of pulses for backlash (play) compensation procedure. Used if ENGINE_ANTIPLAY flag is set. Range: 1..65535 \endenglish \russian Количество импульсов энкодера, на которое будет проходить позиционер заданную позицию для подхода к ней с одной и той же стороны. Используется, если установлен флаг ENGINE_ANTIPLAY. Диапазон: 1..65535 \endrussian */
		int microstep_mode;				/**< \english Settings of microstep mode \endenglish \russian Настройки микрошагового режима. \endrussian */
		int type;						/**< \english Defines motor type \endenglish \russian Тип мотора. \endrussian */
	} engine_settings_t;

	/** 
		* \english
		* PID settings.
		* This structure contains factors for PID routines.
		* Range: 0..65535.
		* It specify behaviour of PID routines for position, speed, voltage and current.
		* These factors are slightly different for different positioners.
		* All boards are supplied with standart set of PID setting on controller's flash memory.
		* Please load new PID settings when you change positioner.
		* Please note that wrong PID settings lead to device malfunction
		* \endenglish
		* \russian
		* Настройки ПИД.
		* Эта структура содержит коэффициенты для ПИД регуляторов.
		* Диапазон: 0..65535.
		* Они определяют работу ПИД контуров напряжения, тока, скорости и позиции.
		* Эти коэффициенты хранятся во flash памяти памяти контроллера.
		* Пожалуйста, загружайте новые настройки, когда вы меняете мотор или позиционер.
		* Помните, что неправильные настройки ПИД контуров могут повредить оборудование.
		* \endrussian
		
		* @see set_pid_settings
		* @see get_pid_settings
		*/
	typedef struct
	{
		unsigned int kpi;		/**< \english Proportional gain for current PID routine \endenglish \russian Пропорциональный коэффициент ПИД контура по току \endrussian */
		unsigned int kii;		/**< \english Integral gain for current PID routine \endenglish \russian Интегральный коэффициент ПИД контура по току \endrussian */
		unsigned int kdi;		/**< \english Differential gain for current PID routine \endenglish \russian Дифференциальный коэффициент ПИД контура по току \endrussian */
		unsigned int kpu;		/**< \english Proportional gain for voltage PID routine \endenglish \russian Пропорциональный коэффициент ПИД контура по напряжению \endrussian */
		unsigned int kiu;		/**< \english Integral gain for voltage PID routine \endenglish \russian Интегральный коэффициент ПИД контура по напряжению \endrussian */
		unsigned int kdu;		/**< \english Differential gain for voltage PID routine \endenglish \russian Диференциальный коэффициент ПИД контура по напряжению \endrussian */
		unsigned int kprpm;		/**< \english Proportional gain for speed PID routine \endenglish \russian Пропорциональный коэффициент ПИД контура по скорости \endrussian */
		unsigned int kirpm;		/**< \english Integral gain for speed PID routine \endenglish \russian Интегральный коэффициент ПИД контура по скорости \endrussian */
		unsigned int kdrpm;		/**< \english Differential gain for speed PID routine \endenglish \russian Дифференциальный коэффициент ПИД контура по скорости \endrussian */
		unsigned int kppos;		/**< \english Proportional gain for position PID routine \endenglish \russian Пропорциональный коэффициент ПИД контура по позиции \endrussian */
		unsigned int kipos;		/**< \english Integral gain for position PID routine \endenglish \russian Интегральный коэффициент ПИД контура по позиции \endrussian */
		unsigned int kdpos;		/**< \english Differential gain for position PID routine \endenglish \russian Дифференциальный коэффициент ПИД контура по позиции \endrussian */
		unsigned int kpe1;		/**< \english Proportional gain for ext1 PID routine \endenglish \russian Пропорциональный коэффициент ПИД доп1 \endrussian */
		unsigned int kie1;		/**< \english Integral gain for ext1 PID routine \endenglish \russian Интегральный коэффициент ПИД доп1 \endrussian */
		unsigned int kde1;		/**< \english Differential gain for ext1 PID routine \endenglish \russian Дифференциальный коэффициент ПИД доп1 \endrussian */
		unsigned int kpe2;		/**< \english Proportional gain for ext2 PID routine \endenglish \russian Пропорциональный коэффициент ПИД доп2 \endrussian */
		unsigned int kie2;		/**< \english Integral gain for ext2 PID routine \endenglish \russian Интегральный коэффициент ПИД доп2 \endrussian */
		unsigned int kde2;		/**< \english Differential gain for ext2 PID routine \endenglish \russian Дифференциальный коэффициент ПИД доп2 \endrussian */
		unsigned int kpe3;		/**< \english Proportional gain for ext3 PID routine \endenglish \russian Пропорциональный коэффициент ПИД доп3 \endrussian */
		unsigned int kie3;		/**< \english Integral gain for ext3 PID routine \endenglish \russian Интегральный коэффициент ПИД доп3 \endrussian */
		unsigned int kde3;		/**< \english Differential gain for ext3 PID routine \endenglish \russian Дифференциальный коэффициент ПИД доп3 \endrussian */
	} pid_settings_t;

	/** 
		* \english
		* Synchronization settings.
		* This structure contains all synchronization settings, modes, periods and flags.
		* It specify behaviour of synchronization In/Out.
		* All boards are supplied with standart set of these settings
		* \endenglish
		* \russian
		* Настройки синхронизации.
		* Эта структура содержит все настройки, определяющие поведение входа\выхода синхронизации.
		* \endrussian
		* @see get_sync_settings
		* @see set_sync_settings
		*/
	typedef struct 
	{
		unsigned int setup_flags;		/**< \english Generic setup flags \endenglish \russian Основные флаги синхронизации \endrussian */
		unsigned int syncin_flags;		/**< \english Input synchronization flags \endenglish \russian Флаги синхронизации входа \endrussian */
		unsigned int syncout_flags;		/**< \english Output synchronization flags \endenglish \russian Флаги синхронизации выхода \endrussian */
		SyncPinMode sync_pin_mode;		/**< \english Synchronization pin mode \endenglish \russian Тип вывода синхронизации \endrussian */
		unsigned int impulse_time;		/**< \english Output synchronization pulse duration or input synchronization pulse dead time. Range: 0..65535 \endenglish \russian Длительность импульса синхронизации для выхода или задержка защиты от дребезга для входа. Диапазон: 0..65535 \endrussian */
		unsigned int impulse_period;	/**< \english This value specify number of encoder pulses between two output synchronization pulses when TTL_SYNCOUT_ONPERIOD is set. Range: 0..65535 \endenglish \russian Период генерации импульсов, используется при установленном флаге TTL_SYNCOUT_ONPERIOD. Диапазон: 0..65535 \endrussian */
	} sync_settings_t;

	/** 
		* \english
		* Position calibration settings.
		* This structure contains settings used in position calibrating.
		* It specify behaviour of calibrating position.
		* \endenglish
		* \russian
		* Настройки калибровки позиции.
		* Эта структура содержит настройки, использующиеся при калибровке позиции.
		* \endrussian
		* @see get_home_settings
		* @see set_home_settings
		* @see command_home
		*/
	typedef struct 
	{
		int fast_home;			/**< \english Speed used for fast motion. Range: 1..65535. \endenglish \russian Скорость быстрого движения. Диапазон: 1..32767. \endrussian */
		int slow_home;			/**< \english Speed used for slow motion. Range: 1..65535. \endenglish \russian Скорость медленного движения.  Диапазон: 1..65535. \endrussian */
		unsigned int delta;		/**< \english Distance from break point. Range: 0..2147483647 \endenglish \russian Расстояние отхода от точки останова. Диапазон: 0..2147483647. \endrussian */
		unsigned int flags;		/**< \english Set of flags specify direction and stopping conditions. \endenglish \russian Набор флагов, определяющие такие  параметры, как направление и условия останова. \endrussian */
	} home_settings_t;

	/** 
		* \english
		* Analog data.
		* This structure contains raw analog data from ADC embedded on board.
		* These data used for device testing and deep recalibraton by manufacturer only
		* \endenglish
		* \russian
		* Аналоговые данные.
		* Эта структура содержит необработанные данные с АЦП и нормированные значения.
		* Эти данные используются в сервисных целях для тестирования и калибровки устройства.
		* \endrussian
		* @see get_analog_data
		*/
	typedef struct
	{
		int adc_va1;			/**< \english "Voltage on pin 1 winding A" raw data from ADC \endenglish \russian "Выходное напряжение на 1 выводе обмотки А" необработанные данные с АЦП \endrussian */
		int adc_va2;			/**< \english "Voltage on pin 2 winding A" raw data from ADC \endenglish \russian "Выходное напряжение на 2 выводе обмотки А" необработанные данные с АЦП \endrussian */
		int adc_vb1;			/**< \english "Voltage on pin 1 winding B" raw data from ADC \endenglish \russian "Выходное напряжение на 1 выводе обмотки B" необработанные данные с АЦП \endrussian */
		int adc_vext;			/**< \english "External voltage" raw data from ADC \endenglish \russian "Напряжение питания" необработанные данные с АЦП \endrussian */
		int adc_vsup;			/**< \english "Voltage on the top of MOSFET full brige" raw data from ADC \endenglish \russian "Напряжение питания ключей Н-моста" необработанные данные с АЦП \endrussian */
		int adc_acur;			/**< \english "Winding A current" raw data from ADC \endenglish \russian "Ток через обмотку А" необработанные данные с АЦП \endrussian */
		int adc_bcur;			/**< \english "Winding B current" raw data from ADC \endenglish \russian "Ток через обмотку B" необработанные данные с АЦП \endrussian */
		int adc_fullcur;		/**< \english "Full current" raw data from ADC \endenglish \russian "Полный ток" необработанные данные с АЦП \endrussian */
		int adc_pot;			/**< \english Voltage on "Potentiometer", raw data from ADC \endenglish \russian "Потенциометр" необработанные данные с АЦП \endrussian */
		int adc_tempkey;		/**< \english Voltage from temperature sensor, raw data from ADC \endenglish \russian Напряжение с датчика температуры, необработанные данные с АЦП \endrussian */
		int cdc_va1;			/**< \english "Voltage on pin 1 winding A" calibrated data \endenglish \russian "Выходное напряжение на 1 выводе обмотки А" откалиброванные данные \endrussian */
		int cdc_va2;			/**< \english "Voltage on pin 2 winding A" calibrated data \endenglish \russian "Выходное напряжение на 2 выводе обмотки А" откалиброванные данные \endrussian */
		int cdc_vb1;			/**< \english "Voltage on pin 1 winding B" calibrated data \endenglish \russian "Выходное напряжение на 1 выводе обмотки B" откалиброванные данные \endrussian */
		int cdc_vext;			/**< \english "External voltage" calibrated data \endenglish \russian "Напряжение питания" откалиброванные данные \endrussian */
		int cdc_vsup;			/**< \english "Voltage on the top of MOSFET full brige" calibrated data \endenglish \russian "Напряжение питания ключей Н-моста" откалиброванные данные \endrussian */
		int cdc_acur;			/**< \english "Winding A current" calibrated data \endenglish \russian "Ток через обмотку А" откалиброванные данные \endrussian */
		int cdc_bcur;			/**< \english "Winding B current" calibrated data \endenglish \russian "Ток через обмотку B" откалиброванные данные \endrussian */
		int cdc_fullcur;		/**< \english "Full current" calibrated data \endenglish \russian "Полный ток" откалиброванные данные \endrussian */
		int cdc_tempkey;		/**< \english Temperature, calibrated data \endenglish \russian Температура, откалиброванные данные \endrussian */
		int cdc_dutycycle;		/**< \english Duty cycle of PWM \endenglish \russian Коэффициент заполнения ШИМ \endrussian */
	} analog_data_t;

	// ------------------------------------

	/** 
		\english
		@name Boards and drivers control
		* Functions for searching and opening/closing devices
		\endenglish
		\russian
		@name Управление устройством
		* Функции поиска и открытия/закрытия устройств
		\endrussian
		*/
	//@{

	/**
		* \english
		* Open a device with OS name \a name and return identifier of the device which can be used in XIDC calls.
		* @param[in] name - a device name - e.g. COM3 or /dev/tty.s123
		* \endenglish
		* \russian
		* Открывает устройство по имени \a name и возвращает идентификатор, который будет использоваться для обращения к устройству.
		* @param[in] name - имя устройства, например COM3 или /dev/tty.s123
		* \endrussian
		*/
	device_t DCCONTROL_API open_device (const char* name);

	/**
		* \english
		* Close specified device 
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Закрывает устройство
		* @param id - идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API close_device (device_t id);

	/**
		* \english
		* Check if a device with OS name \a name is XIMC device.
		* Be carefuly with this call because it sends some data to the device.
		* @param[in] name - a device name
		* \endenglish
		* \russian
		* Проверяет, является ли устройство с именем \a name XIMC-совместимым.
		* Будте осторожны с вызовом этой функции для неизвестных устройств, т.к. она отправляет данные.
		* @param[in] name - имя устройства
		* \endrussian
		*/
	result_t DCCONTROL_API probe_device (const char* name);

	/**
		* \english
		* Enumerate all devices that looks like XIDC valid.
		* Value passed at \a name_count should specify size of allocated in \a names array.
		* Strings in array \a names must be freed by \a free_enumerate_devices
		* @param[in,out] name_count count of found devices
		* @param[out] names pointer to allocated by caller array
		* @param[in] probe_devices probe devices if non-zero. Range: 0..INT_MAX
		* \endenglish
		* \russian
		* Перечисляет все XIMC-совместимые устройства.
		* Значение \a name_count определяет количество найденных устройств, их имена хранятся в массиве \a names.
		* Память, выделенная этой функцией для массива имен \a names должна быть освобождена с помощью \a free_enumerate_devices.
		* @param[in,out] name_count количество найденных устройств
		* @param[out] names указатель на массив имен
		* @param[in] probe_devices если не равно 0, проверяет устройства на совместимость. Диапазон: 0..INT_MAX
		* \endrussian
		*/
	result_t DCCONTROL_API enumerate_devices(int* name_count, char*** names, int probe_devices);

	/**
		* \english
		* Free memory returned by \a enumerate_devices.
		* Value passed at \a name_count should specify size of allocated in \a names array
		* @param[in] name_count count of elements in \a names
		* @param[in] names memory with devices info
		* \endenglish
		* \russian
		* Освобождает память, выделенную \a enumerate_devices.
		* Значение \a name_count определяет размер массива имен \a names.
		* @param[in] name_count количество элементов в \a names
		* @param[in] names динамический массив имен
		* \endrussian
	*/
	result_t DCCONTROL_API free_enumerate_devices (int name_count, char** names);

	/**
		* \english
		* Init device
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Инициализация устройства
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API init_device (device_t id);

	/**
		* \english
		* Deinit device. Return inited device to initial state. For comunication with this device use \a init_device function ones more time
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Деинициализация устройства. Чтобы начать работать с устройством необходимо вызвать \a init_device
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API deinit_device (device_t id);

	/**
		* \english
		* Return device information.
		* Works with both raw or initialized device.
		* @param id an identifier of device
		* @param[out] manufacturer manufacturer name
		* @param[out] manufacturer_id identifier of manufacturer
		* @param[out] product_description product description
		* \endenglish
		* \russian
		* Возвращает информацию об устройстве. 
		* Команда доступна как из инициализированного состояния, так и из исходного.
		* @param id идентификатор устройства.
		* @param[out] manufacturer имя производителя
		* @param[out] manufacturer_id идентификатор производителя
		* @param[out] product_description описание устройства
		* \endrussian
		*/
	result_t DCCONTROL_API get_device_information (device_t id, char* manufacturer, char* manufacturer_id, char* product_description);

	/** \english
		* Reset library locks in a case of deadlock.
		* \endenglish
		* \russian
		* Снимает блокировку библиотеки в экстренном случае.
		* \endrussian
		*/
	result_t DCCONTROL_API reset_locks ();
	//@}
	


	/** \english
		@name Engine control
		* Main functions for controlling engine movement
		\endenglish
		\russian
		@name Управление мотором
		* Основные функции для управления движением мотора.
		\endrussian
		*/

	//@{

	/**
		* \english
		* Move engine to position \a pos
		* @param pos position to move. Range: 0..4294967295
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Движение в заданную позицию \a pos.
		* @param pos заданная позиция. Диапазон: 0..4294967295
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_move (device_t id, unsigned int pos);

	/**
		* \english
		* Move engine to the distance \a offset relatively to initial position
		* @param offset shift from initial position. Range: -2147483647..2147483647
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Смещение на заданную позицию относительно текущей, или заданной последней командой \a command_move
		* @param offset смещение. Диапазон: -2147483647..2147483647
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_movr (device_t id, int offset);

	/**
		* \english
		* Start continous moving to the left
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Движение влево
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_left (device_t id);

	/**
		* \english
		* Start continous moving to the right
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Движение вправо
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_right (device_t id);

	/**
		* \english
		* Stop engine
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Остановка
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_stop (device_t id);

	/**
		* \english
		* Reset current position to zero
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Установка текущей позиции в 0
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_zero (device_t id);

	/**
		* \english
		* Position calibrating
			Move in direction, defined by HOME_DIR_FAST (right, if set; otherwise - left) with speed home_settings_t::fast_home.
			If HOME_STOP_FAST is set, motor stops by synchronization input activity; otherwise - by limit switch.
			Shift in reverse direction to home_settings_t::home_delta with speed home_settings_t::slow_home.
			Move in direction, defined by HOME_DIR_SLOW (right, if set; otherwise - left) with speed home_settings_t::slow_home.
			If HOME_STOP_SLOW is set, motor stops by limit switch; otherwise - by synchronization input activity.
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Калибровка позиции. 
			Вращает мотор в сторону, заданную HOME_DIR_FAST (если установлен - вправо; иначе - влево) со скоростью home_settings_t::fast_home.
			Если HOME_STOP_FAST установлен, мотор останавливается при поступлении сигнала со входа синхронизации; иначе - при достижении концевого выключателя.
			Вращает мотор в обратную сторону на расстояние home_settings_t::home_delta со скоростью home_settings_t::slow_home. 
			Вращает мотор в сторону, заданную HOME_DIR_SLOW (если установлен - вправо; иначе - влево) со скоростью home_settings_t::slow_home. 
			Если HOME_STOP_SLOW установлен, мотор останавливается при достижении концевого выключателя; иначе - при поступлении сигнала со входа синхронизации.
		* @param id идентификатор устройства
		* \endrussian
		@see home_settings_t
		@see get_home_settings
		@see set_home_settings
		*/
	result_t DCCONTROL_API command_home (device_t id);

	/**
		* \english
		* Return device state.
		* Useful function that fill structure with snapshot of controller status, including speed, position and boolean flags
		* @param id an identifier of device
		* @param[out] state structure with snapshot of controller status
		* \endenglish
		* \russian
		* Возвращает информацию о текущем состоянии устройства.
		* @param id идентификатор устройства
		* @param[out] state структура с информацией о текущем состоянии устройства
		* \endrussian
		*/
	result_t DCCONTROL_API get_status (device_t id, state_t* state);

	//@}


	/** \english
		@name Engine setup
		* Functions for adjusting engine read/write almost all controller settings
		\endenglish
		\russian
		@name Настройки привода
		* Функции для чтения/записи большинства настроек контроллера
		\endrussian
		*/

	//@{

	/**
		* \english
		* Read pwm frequency
		* @param id an identifier of device
		* @param[out] freq frequency
		* \endenglish
		* \russian
		* Чтение частоты ШИМ
		* @param id идентификатор устройства
		* @param[out] freq частота
		* \endrussian
		*/
	result_t DCCONTROL_API get_pwm_freq (device_t id, unsigned int* freq);

	/**
		* \english
		* Set pwm frequency
		* @param id an identifier of device
		* @param[in] freq frequency. Range: 1000..65535
		* \endenglish
		* \russian
		* Запись частоты ШИМ
		* @param id идентификатор устройства
		* @param[in] freq частота. Диапазон: 1000..65535
		* \endrussian
		*/
	result_t DCCONTROL_API set_pwm_freq (device_t id, unsigned int freq);

	/**
		* \english
		* Read feedback settings
		* @param id an identifier of device
		* @param[out] ips number of encoder pulses per shaft revolution
		* @param[out] feedback_flags flags of feedback
		* \endenglish
		* \russian
		* Чтение настроек обратной связи
		* @param id идентификатор устройства
		* @param[out] ips разрешение энкодера (импульсов на оборот)
		* @param[out] feedback_flags флаги обратной связи 
		* \endrussian
		*/
	result_t DCCONTROL_API get_feedback_settings (device_t id, unsigned int* ips, unsigned int* feedback_flags);

	/**
		* \english
		* Set feedback settings
		* @param id an identifier of device
		* @param[in] ips number of encoder pulses per shaft revolution. Range: 1..65535
		* @param[in] feedback_flags flags of feedback 
		* \endenglish
		* \russian
		* Запись настроек обратной связи
		* @param id идентификатор устройства
		* @param[in] ips разрешение энкодера (импульсов на оборот). Диапазон: 1..65535
		* @param[in] feedback_flags флаги обратной связи 
		* \endrussian
		*/
	result_t DCCONTROL_API set_feedback_settings (device_t id, unsigned int ips, unsigned int feedback_flags);

	/**
		* \english
		* Read specified motor shaft speed and acceleration
		* @param id an identifier of device
		* @param[out] rpm motor shaft speed, RPM
		* @param[out] accel motor shaft acceleration, RPM/s
		* @param[out] tuneup_threshold threshold for enabling tuneup
		* \endenglish
		* \russian
		* Чтение настроек движения.
		* @param id идентификатор устройства
		* @param[out] rpm скорость, RPM
		* @param[out] accel ускорение, RPM/с
		* @param[out] tuneup_threshold расстояние от заданной позиции, на котором включается режим tuneup
		* \endrussian
		*/
	result_t DCCONTROL_API get_move_settings (device_t id, unsigned int* rpm, unsigned int* accel, unsigned int* tuneup_threshold);

	/**
		* \english
		* Set specified for this and next motion motor shaft speed and acceleration
		* @param id an identifier of device
		* @param[in] rpm Motor shaft speed, RPM. Range: 1..65535
		* @param[in] accel motor shaft acceleration, RPM/s. Range: 1..65535
		* @param[in] tuneup_threshold threshold for enabling tuneup. Range: 1..65535
		* \endenglish
		* \russian
		* Запись настроек движения
		* @param id идентификатор устройства
		* @param[in] rpm скорость, RPM. Диапазон: 1..65535
		* @param[in] accel ускорение, RPM/с. Диапазон: 1..65535
		* @param[in] tuneup_threshold расстояние от заданной позиции, на котором включается режим tuneup. Диапазон: 1..65535
		* \endrussian
		*/
	result_t DCCONTROL_API set_move_settings (device_t id, unsigned int rpm, unsigned int accel, unsigned int tuneup_threshold);

	/**
		* \english
		* Read engine settings.
		* This function fill structure with set of useful motor settings stored in controller's memory.
		* These settings specify motor shaft movement algorithm, list of limitations and rated characteristics
		* @see set_engine_settings
		* @param id an identifier of device
		* @param[out] engine_settings engine settings
		* \endenglish
		* \russian
		* Чтение настроек мотора.
		* @see set_engine_settings
		* @param id идентификатор устройства
		* @param[out] engine_settings структура с настройками мотора
		* \endrussian
		*/
	result_t DCCONTROL_API get_engine_settings (device_t id, engine_settings_t* engine_settings);

	/**
		* \english
		* Set engine settings.
		* This function send structure with set of engine settings to controller's memory.
		* These settings specify motor shaft movement algorithm, list of limitations and rated characteristics.
		* Use it when you change motor, encoder, positioner etc.
		* Please note that wrong engine settings lead to device malfunction, can lead to irreversible damage of board
		* @see get_engine_settings
		* @param id an identifier of device
		* @param[in] engine_settings engine settings
		* \endenglish
		* \russian
		* Запись настроек мотора.
		* @see get_engine_settings
		* @param id идентификатор устройства
		* @param[in] engine_settings структура с настройками мотора
		* \endrussian
		*/
	result_t DCCONTROL_API set_engine_settings (device_t id, const engine_settings_t* engine_settings);

	/**
		* \english
		* Read engine voltage, current and temperature maxumum ratings.
		* If one of these litims exceed engine will be stopped and de-energized, corresponding flag in state_t structuse will be set
		* @see state_t::flags
		* @param id an identifier of device
		* @param[out] critical_curr maxumum current rating, if it will be exceed STATE_OVERLOAD_CURRENT flag in state_t structuse will be set
		* @param[out] critical_voltage maxumum voltage rating, if it will be exceed STATE_OVERLOAD_VOLTAGE flag in state_t structure will be set
		* @param[out] critical_temp maxumum temperature rating, if it will be exceed STATE_OVERHEAT flag in state_t structuse will be set
		* \endenglish
		* \russian
		* Чтение критических значений напряжения, тока и температуры.
		* Если одно из этих значений превышено, контроллер отключает все силовые выходы и устанавливает соответствующий флаг в структуре state_t. 
		* Время реакции меньше 1 мс.
		* @see state_t::flags
		* @param id идентификатор устройства
		* @param[out] critical_curr критический ток, при превышении устанавливается флан STATE_OVERLOAD_CURRENT структуры state_t
		* @param[out] critical_voltage критическое напряжение, при превышении устанавливается флаг STATE_OVERLOAD_VOLTAGE структуры state_t
		* @param[out] critical_temp критическая температура, при превышении устанавливается флаг STATE_OVERHEAT структуры state_t
		* \endrussian
		*/
	result_t DCCONTROL_API get_secure_settings (device_t id, unsigned int* critical_curr, unsigned int* critical_voltage, unsigned int* critical_temp);

	/**
		* \english
		* Set engine voltage, current and temperature maxumum ratings.
		* If one of these litims exceed engine will be stopped and de-energized, corresponding flag in state_t structuse will be set.
		* Use this function when you change motor, encoder, positioner etc.
		* Please note that wrong maxumum ratings can lead to irreversible damage of motor
		* @see state_t::flags
		* @param id an identifier of device
		* @param[in] critical_curr maxumum current rating, if it will be exceed STATE_OVERLOAD_CURRENT flag in state_t structure will be set. Range: 1..65535
		* @param[in] critical_voltage maxumum voltage rating, if it will be exceed STATE_OVERLOAD_VOLTAGE flag in state_t structure will be set. Range: 1..65535
		* @param[in] critical_temp maxumum temperature rating, if it will be exceed STATE_OVERHEAT flag in state_t structure will be set. Range: 0..65535
		* \endenglish
		* \russian
		* Запись критических значений напряжения, тока и температуры.
		* Если одно из этих значений превышено, контроллер отключает все силовые выходы и устанавливает соответствующий флаг в структуре state_t. 
		* Время реакции меньше 1 мс.
		* @see state_t::flags
		* @param id идентификатор устройства
		* @param[in] critical_curr критический ток, при превышении устанавливается флан STATE_OVERLOAD_CURRENT структуры state_t. Диапазон: 1..65535
		* @param[in] critical_voltage критическое напряжение, при превышении устанавливается флаг STATE_OVERLOAD_VOLTAGE структуры state_t. Диапазон: 1..65535
		* @param[in] critical_temp критическая температура, при превышении устанавливается флаг STATE_OVERHEAT структуры state_t. Диапазон: 0..65535
		* \endrussian
		*/
	result_t DCCONTROL_API set_secure_settings (device_t id, unsigned int critical_curr, unsigned int critical_voltage, unsigned int critical_temp);

	/**
		* \english
		* Read border and limit switches settings
		* @see set_edges_settings
		* @param id an identifier of device
		* @param[out] border_flags border flags, specify types of borders and motor behaviour on borders
		* @param[out] enders_flags ender flags, specify electrical behaviour of limit switches like order and pulled positions
		* @param[out] left left border position, used if BORDER_IS_ENCODER flag is set
		* @param[out] right right border position, used if BORDER_IS_ENCODER flag is set
		* \endenglish
		* \russian
		* Чтение настроек границ и концевых выключателей
		* @see set_edges_settings
		* @param id идентификатор устройства
		* @param[out] border_flags флаги, определяющие тип границ и поведение мотора при их достижении
		* @param[out] enders_flags флаги, определяющие настройки концевых выключателей
		* @param[out] left позиция левой границы, используется если установлен флаг BORDER_IS_ENCODER
		* @param[out] right позиция правой границы, используется если установлен флаг BORDER_IS_ENCODER
		* \endrussian
		*/
	result_t DCCONTROL_API get_edges_settings (device_t id, int* border_flags, int* enders_flags, int* left, int* right);

	/**
		* \english
		* Set border and limit switches settings
		* @param id an identifier of device
		* @param[in] border_flags border flags, specify types of borders and motor behaviour on borders
		* @param[in] enders_flags ender flags, specify electrical behaviour of limit switches like order and pulled positions
		* @param[in] left left border position, used if BORDER_IS_ENCODER flag is set. Range: -2147483647..2147483647
		* @param[in] right right border position, used if BORDER_IS_ENCODER flag is set. Range: -2147483647..2147483647
		* \endenglish
		* \russian
		* Запись настроек границ и концевых выключателей
		* @param id идентификатор устройства
		* @param[in] border_flags флаги, определяющие тип границ и поведение мотора при их достижении
		* @param[in] enders_flags флаги, определяющие настройки концевых выключателей
		* @param[in] left позиция левой границы, используется если установлен флаг BORDER_IS_ENCODER. Диапазон: -2147483647..2147483647
		* @param[in] right позиция правой границы, используется если установлен флаг BORDER_IS_ENCODER. Диапазон: -2147483647..2147483647
		* \endrussian
		*/
	result_t DCCONTROL_API set_edges_settings (device_t id, int border_flags, int enders_flags, int left, int right);

	/**
		* \english
		* Read PID settings.
		* This function fill structure with set of motor PID settings stored in controller's memory.
		* These settings specify behaviour of PID routines for position, speed, voltage and current.
		* These factors are slightly different for different positioners
		* All boards are supplied with standart set of PID setting on controller's flash memory
		* @see set_pid_settings
		* @param id an identifier of device
		* @param[out] pid_settings pid settings
		* \endenglish
		* \russian
		* Чтение настроек ПИД контуров.
		* Эти настройки определяют поведение контуров позиции, скорости, напряжения и тока.
		* Настройки различны для разных позиционеров.
		* @see set_pid_settings
		* @param id идентификатор устройства
		* @param[out] pid_settings настройки ПИД
		* \endrussian
		*/
	result_t DCCONTROL_API get_pid_settings (device_t id, pid_settings_t* pid_settings);

	/**
		* \english
		* Set PID settings.
		* This function send structure with set of PID factors to controller's memory.
		* These settings specify behaviour of PID routines for position, speed, voltage and current.
		* These factors are slightly different for different positioners.
		* All boards are supplied with standart set of PID setting on controller's flash memory.
		* Please use it for loading new PID settings when you change positioner.
		* Please note that wrong PID settings lead to device malfunction
		* @see get_pid_settings
		* @param id an identifier of device
		* @param[in] pid_settings pid settings
		* \endenglish
		* \russian
		* Запись настроек ПИД контуров.
		* Эти настройки определяют поведение контуров позиции, скорости, напряжения и тока.
		* Настройки различны для разных позиционеров.
		* @see get_pid_settings
		* @param id идентификатор устройства
		* @param[in] pid_settings настройки ПИД
		* \endrussian
		*/
	result_t DCCONTROL_API set_pid_settings (device_t id, const pid_settings_t* pid_settings);

	/**
		* \english
		* Read synchronization settings.
		* This function fill structure with set synchronization settings, modes, periods and flags, that specify behaviour of synchronization In/Out.
		* All boards are supplied with standart set of these settings
		* @see set_sync_settings
		* @param id an identifier of device
		* @param[out] sync_settings synchronization settings
		* \endenglish
		* \russian
		* Чтение настроек синхронизации.
		* Эта функция заполняет структуру с настройками синхронизации, определяющими поведение вывода синхронизации.
		* @see set_sync_settings
		* @param id идентификатор устройства
		* @param[out] sync_settings настройки синхронизации
		* \endrussian
		*/
	result_t DCCONTROL_API get_sync_settings (device_t id, sync_settings_t* sync_settings);

	/**
		* \english
		* Set synchronization settings.
		* This function send structure with set of synchronization settings, that specify behaviour of synchronization In/Out, to controller's memory.
		* All boards are supplied with standart set of these settings
		* @see get_sync_settings
		* @param id an identifier of device
		* @param[in] sync_settings synchronization settings
		* \endenglish
		* \russian
		* Запись настроек синхронизации.
		* Эта функция записывает структуру с настройками синхронизации, определяющими поведение вывода синхронизации, в память контроллера.
		* @see get_sync_settings
		* @param id идентификатор устройства
		* @param[in] sync_settings настройки синхронизации
		* \endrussian
		*/
	result_t DCCONTROL_API set_sync_settings (device_t id, const sync_settings_t* sync_settings);

	/**
		* \english
		* Read home settings.
		* This function fill structure with settings of calibrating position
		* @see home_settings_t
		* @param id an identifier of device
		* @param[out] home_settings calibrating position settings
		* \endenglish
		* \russian
		* Чтение настроек калибровки позиции.
		* Эта функция заполняет структуру настроек, использующихся для калибровки позиции.
		* @see home_settings_t
		* @param id идентификатор устройства
		* @param[out] home_settings настройки калибровки позиции
		* \endrussian
		*/
	result_t DCCONTROL_API get_home_settings(device_t id, home_settings_t* home_settings);

	/**
		* \english
		* Set home settings.
		* This function send structure with calibrating position settings to controller's memory.
		* @see home_settings_t
		* @param id an identifier of device
		* @param[in] home_settings calibrating position settings
		* \endenglish
		* \russian
		* Запись настроек калибровки позиции.
		* Эта функция записывает структуру настроек, использующихся для калибровки позиции, в память контроллера.
		* @see home_settings_t
		* @param id идентификатор устройства
		* @param[out] home_settings настройки калибровки позиции
		* \endrussian
		*/
	result_t DCCONTROL_API set_home_settings(device_t id, const home_settings_t home_settings);

	/**
		* \english
		* Read all settings from controller's flash memory to controller's RAM, replacing previous data in controller's RAM
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Чтение всех настроек контроллера из flash памяти в оперативную, заменяя текущие настройки.
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_read_settings(device_t id);

	/**
		* \english
		* Save all settings from controller's RAM to controller's flash memory, replacing previous data in controller's flash memory
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Запись всех текущих настроек во flash память контроллера.
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_save_settings(device_t id);

	/**
		* \english
		* Read device serial number
		* @param id an identifier of device
		* @param[out] serial serial number
		* \endenglish
		* \russian
		* Чтение серийного номера контроллера
		* @param id идентификатор устройства
		* @param[out] serial serial number
		* \endrussian
		*/
	result_t DCCONTROL_API get_serial_number(device_t id, uint32_t* serial);

	/**
		* \english
		* Read controller's firmware version
		* @param id an identifier of device
		* @param[out] major major version
		* @param[out] minor minor version
		* @param[out] release release version
		* \endenglish
		* \russian
		* Чтение номера версии прошивки контроллера
		* @param id идентификатор устройства
		* @param[out] major номер основной версии
		* @param[out] minor номер дополнительной версии
		* @param[out] release номер релиза
		* \endrussian
		*/
	result_t DCCONTROL_API get_firmware_version(device_t id, unsigned int* major, unsigned int* minor, unsigned int* release);

	/**
		* \english
		* Read analog data structure that contains raw analog data from ADC embedded on board.
		* This function used for device testing and deep recalibraton by manufacturer only
		* @param id an identifier of device
		* @param[out] ad analog data coefficients
		* \endenglish
		* \russian
		* Чтение аналоговых данных, содержащих данные с АЦП и нормированные значения величин.
		* Эта функция используется для тестирования и калибровки устройства.
		* @param id идентификатор устройства
		* @param[out] ad аналоговые данные
		* \endrussian
		*/

	result_t DCCONTROL_API get_analog_data (device_t id, analog_data_t* ad);
	/**
		* \english
		* Return device electrical parameters, useful for charts.
		* Useful function that fill structure with snapshot of controller voltages and currents.
		* @see chart_data_t
		* @param id an identifier of device
		* @param[out] chart_data structure with snapshot of controller parameters.
		* \endenglish
		* \russian
		* Возвращает информацию с электрическими параметрами, удобную для построения графиков.
		* @see chart_data_t
		* @param id идентификатор устройства
		* @param[out] chart_data structure with snapshot of controller parameters.
		* \endrussian
		*/
	result_t DCCONTROL_API get_chart_data (device_t id, chart_data_t* chart_data);

	// @}


	/** \english
		@name Service functions
		* Functions are intended for deep controller setup.
		* There is no necessity to use it during normal operation.
		* These functions have to be used by skilled engineers only.
		* If you want to use it please consult with the manufacturer.
		* Wrong usage lead to device malfunction, can lead to irreversible damage of board 
		\endenglish
		\russian
		@name Сервисные функции
		* Эти функции необходимы для начального конфигурирования, тестирования и обновления устройства.
		* Не применяйте их при обычной работе с контроллером.
		* При необходимости, проконсультируйтесь пожалуйста с производителем.
		* Неправильное использование этих функций может привести к неработоспособности устройства.
		\endrussian
		*/

	//@{

	/**
		* \english
		* Read calibration coefficients.
		* This function fill structure with set of calibration data stored in controller's memory.
		* There is no necessity to use it during normal operation.
		* These data change after special device recalibraton only
		* @see set_calibration_coeffs
		* @param id an identifier of device
		* @param[out] cs calibration coefficients
		* \endenglish
		* \russian
		* Чтение калибровочных коэффициентов.
		* Эта функция заполняет структуру калибровочных коэффициентов, которые хранятся в памяти контроллера.
		* Для обычной работы с устройством эта функция не требуется.
		* Калибровочные коэффициенты применяются для калибровки контроллера.
		* @see set_calibration_coeffs
		* @param id идентификатор устройства
		* @param[out] cs калибровочные коэффициенты
		* \endrussian
		*/
	result_t DCCONTROL_API get_calibration_coeffs(device_t id, calibration_settings_t* cs);

	/**
		* \english
		* Set calibration coefficients.
		* This function send structure with set of calibration data to controller's memory.
		* Note that all boards are supplied with full set of right calibration data.
		* There is no necessity to change it during normal operation.
		* These data have to be changed after special hardware device recalibraton only.
		* If you want to recalibrate board please consult with the manufacturer.
		* Wrong calibration settings lead to device malfunction, can lead to irreversible damage of board 
		* @see get_calibration_coeffs
		* @param id an identifier of device
		* @param[in] cs calibration coefficients
		* \endenglish
		* \russian
		* Запись калибровочных коэффициентов.
		* Эта функция записывает калибровочные коэффициенты во flash контроллера.
		* Все устройства при изготовлении проходят процедуру калибровки и при обычной работе их не требуется изменять.
		* Если вы хотите произвести калибровку устройства, проконсультируйтесь с производителем.
		* Установка неправильных коэффициентов может стать причиной перегрева и выхода контроллера из строя.
		* @see get_calibration_coeffs
		* @param id идентификатор устройства
		* @param[in] cs калибровочные коэффициенты
		* \endrussian
		*/
	result_t DCCONTROL_API set_calibration_coeffs(device_t id, const calibration_settings_t* cs);

	/**
		* \english
		* Open a device with OS name \a name and return identifier of the device which can be used in XIDC calls.
		* Device can be raw, i.e. without firmware.
		* @param[in] name - a COM device name - e.g. COM3 or /dev/tty.s123
		* \endenglish
		* \russian
		* Открывает устройство по имени \a name и возвращает идентификатор, который будет использоваться для обращения к устройству.
		* Устройство может быть чистым, без прошивки.
		* @param[in] name - имя устройства, например COM3 или /dev/tty.s123
		* \endrussian
		*/
	device_t DCCONTROL_API open_raw_device (const char* name);

	/**
		* \english
		* Write device serial number to controller's flash memory.
		* Can be used by manufacturer only
		* @param id an identifier of device
		* @param[in] serial serial number. Range: 0..4294967295
		* @param[in] key protection key. Range: 0..4294967295
		* \endenglish
		* \russian
		* Запись серийного номера во flash память контроллера.
		* Функция используется только производителем.
		* @param id идентификатор устройства
		* @param[in] serial серийный номер. Диапазон: 0..4294967295
		* @param[in] key ключ защиты. Диапазон: 0..4294967295
		* \endrussian
		*/
	result_t DCCONTROL_API set_serial_number(device_t id, uint32_t serial, uint32_t key);

	/**
		* \english
		* Check for firmware on device
		* @param id an identifier of device
		* @param[out] ret non-zero if firmware existed
		* \endenglish
		* \russian
		* Проверка наличия прошивки в контроллере
		* @param id идентификатор устройства
		* @param[out] ret не ноль, если прошивка присутствует
		* \endrussian
		*/
	result_t DCCONTROL_API has_firmware(device_t id, uint8_t* ret);

	/**
		* \english
		* Write controller key.
		* Can be used by manufacturer only
		* @param id an identifier of device
		* @param[in] key protection key. Range: 0..4294967295
		* \endenglish
		* \russian
		* Запись ключа защиты
		* Функция используется только производителем.
		* @param id идентификатор устройства
		* @param[in] key ключ защиты. Диапазон: 0..4294967295
		* \endrussian
		*/
	result_t DCCONTROL_API write_key(device_t id, uint32_t key);

	/**
		* \english
		* Calibrate controller.
		* Can be used by manufacturer only
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Перевод контроллера в состояние калибровки.
		* Функция используется только производителем.
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_calibrate(device_t id);

	/**
		* \english
		* Reset controller.
		* Can be used by manufacturer only
		* @param id an identifier of device
		* \endenglish
		* \russian
		* Перезагрузка контроллера.
		* Функция используется только производителем.
		* @param id идентификатор устройства
		* \endrussian
		*/
	result_t DCCONTROL_API command_reset(device_t id);

	/**
		* \english
		* Update firmware.
		* Service command
		* @param id an identifier of device
		* @param data firmware byte stream
		* @param data_size size of byte stream
		* \endenglish
		* \russian
		* Обновление прошивки
		* @param id идентификатор устройства
		* @param data указатель на массив байтов прошивки
		* @param data_size размер массива в байтах
		* \endrussian
		*/
	result_t DCCONTROL_API command_update_firmware(device_t id, const uint8_t* data, uint32_t data_size);


	//@}

#if defined(__cplusplus)
};
#endif

#endif

